==> hermes-2.4.12.7.tar.gz: hermes-2.4.12.7/app/assets/docs/doc/Scripts.md <==
# Ecriture et execution de script

Afin d'être exécuté de manière correcte, il est préférable que les scripts soient écrits dans des fichiers (.rb) afin d'être joué en étant importé depuis une console rails.

## Execution de script

Exemple d'exécution d'un script avec le contenu suivant :
```ruby
# script_v1.rb

puts 'Hello world !'
```

Se connecter sur la machine cible et effectuer les actions suivantes :
```shell
su - webapp                           # Si pas connecté avec l'utilisateur wepapp
cd /opt/plugandwork/apps/rce/current  # Pour se déplacer dans le répertoire de l'application
nano script_v1.rb                     # Pour créer un fichier nommé script_v1.rb
CTRL-V                                # Pour copier le contenu du script
CTRL+X                                # Pour quitter nano
y                                     # Pour sauvegarder
ENTER                                 # Pour valider et revenir en ligne de commande
bundle exec rails c -e production     # Pour lancer une console rails
require_relative './script_v1'        # Pour executer le script

Hello world !
```

## Récupération des logs
### Chemin
Par défaut, les logs de sortie des scripts seront écrits dans le répertoire de l'application rails soit `'/opt/plugandwork/apps/rce/current'` S'il est nécessaire d'écrire le fichier log dans un autre répertoire, veuillez modifier la variable `FILE_PATH` dans le script afin d'indiquer le chemin souhaité (ex `FILE_PATH = "/home/logs"`).
### Fichier
Par défaut, le fichier de sortie sera nommé sous le format suivant : `{DEV|REC|DEMO|PROD}-{dd-mm-yyyy-H:M}-{script_filename}.{csv|log}`

Exemple pour un script nommé `script_1234_v1.rb` executé en recette le 25 nov 2020 à 14h22, le fichier de sorite sortie sera `REC-25-11-2020-14:22-script_1234_v1.log` ou `REC-25-11-2020-14:22-script_1234_v1.csv`

## Ecriture de script
Afin de suivre les règles et conventions de nommages, merci de bien vouloir écrire les scripts à partir du template suivante :

```ruby
raise 'You need to load this script througth a require' unless __FILE__

# Replace following variables if need
FILE_TYPE = 'csv'
FILE_PATH = "."

def run_script
  start_time = Time.now
  formated_t = start_time.strftime('%d-%m-%Y-%H:%M')
  puts "Start script at #{start_time}"
  file_name   = "#{HERMES_ENV}-#{formated_t}-#{__FILE__.split('/').last.gsub('.rb', ".#{FILE_TYPE}")}"
  file_class  = FILE_TYPE == 'csv' ? CSV : File
  file        = file_class.open("#{FILE_PATH}/#{file_name}", 'ab')
  ##############################################################################
  ##################################__SCRIPT__##################################
  # write the content of the script bellow
  ressources = []

  puts "Found #{ressources.count} matching ressources"

  file << ['header_01']
  # file.write('value') if FILE_TYPE == 'log'

  ressources.each do |ressource|
    file << [ressource.field]
    # file.write(ressource.field) if FILE_TYPE == 'log'
  end
  ##############################################################################
  ##############################################################################
  file.close
  stop_time = Time.now
  puts "Start end at #{stop_time}"
  puts "Executed in #{(stop_time - start_time).seconds}"
end

run_script
```

==> hermes-5.3.0.18.tar.gz: hermes-5.3.0.18/app/assets/docs/doc/Scripts.md <==
# Ecriture et execution de script

Afin d'être exécuté de manière correcte, il est préférable que les scripts soient écrits dans des fichiers (.rb) afin d'être joué en étant importé depuis une console rails.

## Execution de script

Exemple d'exécution d'un script avec le contenu suivant :
```ruby
# script_v1.rb

puts 'Hello world !'
```

Se connecter sur la machine cible et effectuer les actions suivantes :
```shell
su - webapp                           # Si pas connecté avec l'utilisateur wepapp
cd /opt/plugandwork/apps/rce/current  # Pour se déplacer dans le répertoire de l'application
nano script_v1.rb                     # Pour créer un fichier nommé script_v1.rb
CTRL-V                                # Pour copier le contenu du script
CTRL+X                                # Pour quitter nano
y                                     # Pour sauvegarder
ENTER                                 # Pour valider et revenir en ligne de commande
bundle exec rails c -e production     # Pour lancer une console rails
require_relative './script_v1'        # Pour executer le script

Hello world !
```

## Récupération des logs
### Chemin
Par défaut, les logs de sortie des scripts seront écrits dans le répertoire de l'application rails soit `'/opt/plugandwork/apps/rce/current'` S'il est nécessaire d'écrire le fichier log dans un autre répertoire, veuillez modifier la variable `FILE_PATH` dans le script afin d'indiquer le chemin souhaité (ex `FILE_PATH = "/home/logs"`).
### Fichier
Par défaut, le fichier de sortie sera nommé sous le format suivant : `{DEV|REC|DEMO|PROD}-{dd-mm-yyyy-H:M}-{script_filename}.{csv|log}`

Exemple pour un script nommé `script_1234_v1.rb` executé en recette le 25 nov 2020 à 14h22, le fichier de sorite sortie sera `REC-25-11-2020-14:22-script_1234_v1.log` ou `REC-25-11-2020-14:22-script_1234_v1.csv`

## Ecriture de script
Afin de suivre les règles et conventions de nommages, merci de bien vouloir écrire les scripts à partir du template suivante :

```ruby
raise 'You need to load this script througth a require' unless __FILE__

# Replace following variables if need
FILE_TYPE = 'csv'
FILE_PATH = "."

def run_script
  start_time = Time.now
  formated_t = start_time.strftime('%d-%m-%Y-%H:%M')
  puts "Start script at #{start_time}"
  file_name   = "#{HERMES_CONFIG['environment']}-#{formated_t}-#{__FILE__.split('/').last.gsub('.rb', ".#{FILE_TYPE}")}"
  file_class  = FILE_TYPE == 'csv' ? CSV : File
  file        = file_class.open("#{FILE_PATH}/#{file_name}", 'ab')
  ##############################################################################
  ##################################__SCRIPT__##################################
  # write the content of the script bellow
  ressources = []

  puts "Found #{ressources.count} matching ressources"

  file << ['header_01']
  # file.write('value') if FILE_TYPE == 'log'

  ressources.each do |ressource|
    file << [ressource.field]
    # file.write(ressource.field) if FILE_TYPE == 'log'
  end
  ##############################################################################
  ##############################################################################
  file.close
  stop_time = Time.now
  puts "Start end at #{stop_time}"
  puts "Executed in #{(stop_time - start_time).seconds}"
end

run_script
```
